# TorchGlyph

![Unit Tests](https://github.com/speedcell4/torchglyph/workflows/Unit%20Tests/badge.svg)
[![PyPI version](https://badge.fury.io/py/torchglyph.svg)](https://badge.fury.io/py/torchglyph)
[![Downloads](https://pepy.tech/badge/torchglyph)](https://pepy.tech/project/torchglyph)

Data Processor Combinators for Natural Language Processing.

## Requirements

- Python 3.7
- PyTorch 1.6.0

## Installation

`python -m pip install torchglyph`
